#ifndef PLUGINSETTINGS_H
#define PLUGINSETTINGS_H

#include <QMainWindow>
#include <QtGui>

namespace Ui {
    class PluginSettings;
}
class PluginInterface;
class PluginSettings : public QMainWindow {
    Q_OBJECT
public:
    PluginSettings(QList<PluginInterface*> pluginInterfaces, QWidget *parent = 0);
    ~PluginSettings();

    QStandardItemModel *model;
    QHash<int, PluginInterface*> idToInterface;

protected:
    void changeEvent(QEvent *e);

private:
    Ui::PluginSettings *ui;

private slots:
    void on_tblPlugins_clicked(QModelIndex index);
};

#endif // PLUGINSETTINGS_H
